@@ -1,7 +1,7 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
   Copyright(C) 2011-2013 Kentoku SHIBA
-  Copyright(C) 2011-2013 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2011-2014 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -50,11 +50,13 @@
 extern HASH *mrn_table_def_cache;
 #endif
 
-#ifdef MRN_TABLE_SHARE_HAVE_LOCK_SHARE
+#ifdef WIN32
+#  ifdef MRN_TABLE_SHARE_HAVE_LOCK_SHARE
 extern PSI_mutex_key *mrn_table_share_lock_share;
-#endif
-#ifdef MRN_TABLE_SHARE_HAVE_LOCK_HA_DATA
+#  endif
+#  ifdef MRN_TABLE_SHARE_HAVE_LOCK_HA_DATA
 extern PSI_mutex_key *mrn_table_share_lock_ha_data;
+#  endif
 #endif
 
 #ifdef __cplusplus
@@ -278,7 +280,7 @@ void mrn_get_partition_info(const char *table_name, uint table_name_length,
   if (!strncasecmp(tmp_ptr, title_name, title_length)) \
   { \
     DBUG_PRINT("info", ("mroonga "title_name" start")); \
-    if (!share->param_name[param_pos]) \
+    if (share->param_name && !share->param_name[param_pos]) \
     { \
       if ((share->param_name[param_pos] = mrn_get_string_between_quote( \
         start_ptr))) \
@@ -968,7 +970,9 @@ TABLE_SHARE *mrn_get_table_share(TABLE_LIST *table_list, int *error)
                           hash_value);
 #elif defined(MRN_HAVE_TDC_ACQUIRE_SHARE)
   share = tdc_acquire_share(thd, table_list->db, table_list->table_name, key,
-                            key_length, GTS_TABLE, NULL);
+                            key_length,
+                            table_list->mdl_request.key.tc_hash_value(),
+                            GTS_TABLE, NULL);
 #else
   share = get_table_share(thd, table_list, key, key_length, 0, error);
 #endif
